@@ -34,6 +34,10 @@
 #include <KMessageBox>
 #include <KSharedConfig>
 
+namespace {
+    const int MAX_GPT_PARTITION_LABLE_LENGTH = 36;
+}
+
 /** Creates a new PartPropsDialog
     @param parent pointer to the parent widget
     @param d the Device the Partition is on
@@ -68,6 +72,11 @@ PartPropsDialog::~PartPropsDialog()
     kcg.writeEntry("Geometry", saveGeometry());
 }
 
+QString PartPropsDialog::newPartitionLabel() const
+{
+    return dialogWidget().partitionLabel().text();
+}
+
 /** @return the new label */
 QString PartPropsDialog::newLabel() const
 {
@@ -132,10 +141,10 @@ void PartPropsDialog::setupDialog()
     dialogWidget().uuid().setText(partition().fileSystem().uuid().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().fileSystem().uuid());
 
     if(device().partitionTable()->type() == PartitionTable::gpt){
-        QString PartitionLabel = partition().label().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().label();
         QString PartitionUUID = partition().uuid().isEmpty() ? xi18nc("@item uuid", "(none)") : partition().uuid();
 
-        dialogWidget().partitionLabel().setText(PartitionLabel);
+        dialogWidget().partitionLabel().setMaxLength(MAX_GPT_PARTITION_LABLE_LENGTH);
+        dialogWidget().partitionLabel().setText(partition().label());
         dialogWidget().partitionUuid().setText(PartitionUUID);
 
         // On GPT there are no logical or extended partitions.
@@ -159,12 +168,8 @@ void PartPropsDialog::setupDialog()
     if (Capacity(partition(), Capacity::Type::Available).isValid()) {
         const qint64 availPercent = (partition().fileSystem().length() - partition().fileSystem().sectorsUsed()) * 100 / partition().fileSystem().length();
 
-        const QString availString = QStringLiteral("%1% - %2")
-                                    .arg(availPercent)
-                                    .arg(Capacity::formatByteSize(partition().available()));
-        const QString usedString = QStringLiteral("%1% - %2")
-                                   .arg(100 - availPercent)
-                                   .arg(Capacity::formatByteSize(partition().used()));
+        const QString availString = i18n("%1% — %2", availPercent, Capacity::formatByteSize(partition().available()));
+        const QString usedString = i18n("%1% — %2", (100 - availPercent), Capacity::formatByteSize(partition().used()));
 
         dialogWidget().available().setText(availString);
         dialogWidget().used().setText(usedString);
@@ -273,7 +278,12 @@ void PartPropsDialog::updateHideAndShow()
 
 void PartPropsDialog::setupConnections()
 {
-    connect(&dialogWidget().label(), &QLineEdit::textEdited, [this] (const QString &) {setDirty();});
+    auto setDirty = [this]() {
+        this->setDirty();
+    };
+
+    connect(&dialogWidget().partitionLabel(), &QLineEdit::textEdited, this, setDirty);
+    connect(&dialogWidget().label(), &QLineEdit::textEdited, this, setDirty);
     connect(&dialogWidget().fileSystem(), &QComboBox::currentIndexChanged, this, &PartPropsDialog::onFilesystemChanged);
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(&dialogWidget().checkRecreate(), &QCheckBox::stateChanged, this, &PartPropsDialog::onRecreate);
@@ -287,7 +297,7 @@ void PartPropsDialog::setupConnections()
     // itemClicked alone isn't enough either. We choose to rather enable the OK-button too often than too
     // seldom.
     connect(&dialogWidget().listFlags(), &QListWidget::itemClicked, this, &PartPropsDialog::setDirty);
-    connect(&dialogWidget().listFlags(), &QListWidget::currentRowChanged, [this] (int) {setDirty();});
+    connect(&dialogWidget().listFlags(), &QListWidget::currentRowChanged, this, setDirty);
 }
 
 void PartPropsDialog::setDirty(void*)
